@@ -83,6 +83,6 @@ begin
     end
   end
 
-rescue LoadError => boom
+rescue LoadError
   warn "Tilt::MarkabyTemplate (disabled)"
 end
